@@ -28,9 +28,7 @@ This needs to be rewritten with a lot of functions cleaned up.
 There are a lot of places where code is unneccesarily duplicated,
 which needs to be better organized via functions */
 
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
+#include "evolution-ews-config.h"
 
 #include <errno.h>
 #include <string.h>
@@ -45,12 +43,11 @@ which needs to be better organized via functions */
 #include <libical/icalparser.h>
 
 #include "server/camel-ews-settings.h"
+#include "server/e-ews-camel-common.h"
 #include "server/e-ews-connection.h"
 #include "server/e-ews-item-change.h"
 #include "server/e-ews-message.h"
 
-#include "utils/ews-camel-common.h"
-
 #include "camel-ews-folder.h"
 #include "camel-ews-private.h"
 #include "camel-ews-store.h"
@@ -1862,16 +1859,12 @@ ews_refresh_info_sync (CamelFolder *folder,
 	do {
 		GSList *items_created = NULL, *items_updated = NULL;
 		GSList *items_deleted = NULL;
-		gchar *new_sync_state = NULL;
 		guint32 total, unread;
 
 		e_ews_connection_sync_folder_items_sync (cnc, EWS_PRIORITY_MEDIUM, sync_state, id, "IdOnly", NULL, EWS_MAX_FETCH_COUNT,
-			&new_sync_state, &includes_last_item, &items_created, &items_updated, &items_deleted,
+			&sync_state, &includes_last_item, &items_created, &items_updated, &items_deleted,
 			cancellable, &local_error);
 
-		g_free (sync_state);
-		sync_state = new_sync_state;
-
 		if (g_error_matches (local_error, EWS_CONNECTION_ERROR, EWS_CONNECTION_ERROR_INVALIDSYNCSTATEDATA)) {
 			g_clear_error (&local_error);
 			camel_ews_summary_set_sync_state ((CamelEwsSummary *) folder->summary, NULL);
