@@ -21,9 +21,7 @@
  *
  */
 
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
+#include "evolution-ews-config.h"
 
 #include <glib/gi18n-lib.h>
 #include <gtk/gtk.h>
@@ -528,13 +526,9 @@ update_permission_dialog_by_level_combo (GObject *dialog)
 	    (!widgets->read_fb_time_radio && ii >= G_N_ELEMENTS (predefined_levels) - 3))
 		return;
 
-	if (!predefined_levels[ii].rights) {
-		rights = predefined_levels[ii].rights;
-	} else {
-		rights = folder_permissions_dialog_to_rights (dialog);
-		rights = predefined_levels[ii].rights | (rights & (E_EWS_PERMISSION_BIT_FREE_BUSY_DETAILED |
-			E_EWS_PERMISSION_BIT_FREE_BUSY_SIMPLE));
-	}
+	rights = folder_permissions_dialog_to_rights (dialog);
+	rights = predefined_levels[ii].rights | (rights & (E_EWS_PERMISSION_BIT_FREE_BUSY_DETAILED |
+		E_EWS_PERMISSION_BIT_FREE_BUSY_SIMPLE));
 
 	widgets->updating++;
 	update_folder_permissions_by_rights (dialog, rights);
@@ -584,7 +578,7 @@ add_button_clicked_cb (GObject *dialog)
 					COL_E_EWS_PERMISSION_USER_TYPE, &ut,
 					-1);
 
-				if (ut == E_EWS_PERMISSION_USER_TYPE_REGULAR && perm && g_strcmp0 (perm->primary_smtp, primary_smtp) == 0) {
+				if (ut == E_EWS_PERMISSION_USER_TYPE_REGULAR && perm && g_strcmp0 (perm->primary_smtp, primary_smtp)) {
 					gtk_tree_selection_select_iter (selection, &iter);
 					found = TRUE;
 					break;
